@@ -17,12 +17,9 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  */
 #include <libaio.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <errno.h>
-#include "vsys_def.h"
+#include "syscall.h"
 
 int io_queue_release(io_context_t ctx)
 {
-	return vsys_io_destroy(ctx);
+	return sys_io_destroy(ctx);
 }
